@@ -7,6 +7,7 @@ import distutils.cmd
 from distutils.errors import DistutilsOptionError
 from distutils.errors import DistutilsSetupError
 from distutils.core import Extension
+from zipfile import ZipFile
 
 import pytest
 
@@ -294,3 +295,11 @@ def test_findall_missing_symlink(tmpdir, can_symlink):
         os.symlink('foo', 'bar')
         found = list(setuptools.findall())
         assert found == []
+
+
+def test_its_own_wheel_does_not_contain_tests(setuptools_wheel):
+    with ZipFile(setuptools_wheel) as zipfile:
+        contents = [f.replace(os.sep, '/') for f in zipfile.namelist()]
+
+    for member in contents:
+        assert '/tests/' not in member
